@@ -1,3 +1,4 @@
+import ssl
 import pika
 import os
 import msgpack
@@ -12,6 +13,7 @@ import logging
 from opentelemetry import trace
 from opentelemetry.trace.propagation.tracecontext import TraceContextTextMapPropagator
 from otel_extensions import instrumented
+from utf_queue_client import DISABLE_SSL_VERIFICATION_DEFAULT
 
 __all__ = ["BaseProducer", "BlockingProducer", "PikaChannel", "ConnectionError"]
 
@@ -129,7 +131,18 @@ class BlockingProducer(BaseProducer):
     @contextmanager
     def __connect(self):
         try:
-            with pika.BlockingConnection(pika.URLParameters(self.url)) as connection:
+            url_params = pika.URLParameters(self.url)
+            if (
+                os.environ.get(
+                    "DISABLE_SSL_VERIFICATION", DISABLE_SSL_VERIFICATION_DEFAULT
+                )
+                == "true"
+            ) and url_params.ssl_options is not None:
+                ssl_context = ssl.create_default_context()  # NOSONAR
+                ssl_context.check_hostname = False  # NOSONAR
+                ssl_context.verify_mode = ssl.CERT_NONE  # NOSONAR
+                url_params.ssl_options = pika.SSLOptions(ssl_context)
+            with pika.BlockingConnection(url_params) as connection:
                 self._connection = connection
                 self._channel = self._connection.channel()
                 yield
