@@ -9,8 +9,7 @@ T = TypeVar("T")
 """
 Maps a model type to a set of defaults
 """
-DEFAULTS_MAP: Dict[Type[BaseModelWithValidation], dict] = {
-}
+DEFAULTS_MAP: Dict[Type[BaseModelWithValidation], dict] = {}
 
 
 def create_model_with_defaults(model_type: Type[T], **kwargs) -> T:
